/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.processor.aggregate;

import org.apache.camel.Exchange;
import org.apache.camel.impl.GroupedExchange;

/**
 * Aggregate all exchanges into a single combined {@link org.apache.camel.impl.GroupedExchange} holding all
 * the exchanges gathered.
 *
 * @version $Revision: 772172 $
 */
public class GroupedExchangeAggregationStrategy implements AggregationStrategy {

    public Exchange aggregate(Exchange oldExchange, Exchange newExchange) {
        GroupedExchange answer;
        if (!(oldExchange instanceof GroupedExchange)) {
            answer = new GroupedExchange(oldExchange);
            answer.addExchange(oldExchange);
        } else {
            answer = (GroupedExchange) oldExchange;
        }

        answer.addExchange(newExchange);
        return answer;
    }

}
